=========
Tornamona
=========




.. image:: https://pyup.io/repos/github/andrewbolster/tornamona/shield.svg
     :target: https://pyup.io/repos/github/andrewbolster/tornamona/
     :alt: Updates



A series of fixes for Data originating from Northern Ireland



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
